package com.sas.drugdev.rapi.permissions;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import com.sas.drugdev.remote.repository.security.AccessControlEntry;
import com.sas.drugdev.remote.repository.security.AccessControlList;
import com.sas.drugdev.remote.repository.security.Permission;

public class ContainerEntry {
	/*
	 * permission codes
	 * format Read/Write/Delete/Manage
	 */
	public static final String NO_PERMISSIONS =			"nnnn";
	public static final String READ_ONLY = 				"ynnn";
	public static final String READ_WRITE = 			"yynn";
	public static final String READ_DELETE = 			"ynyn";
	public static final String READ_MANAGE = 			"ynny";
	public static final String READ_WRITE_DELETE = 		"yyyn";
	public static final String READ_WRITE_MANAGE = 		"yyny";
	public static final String READ_DELETE_MANAGE = 	"ynyy";
	public static final String WRITE_ONLY = 			"nynn";
	public static final String WRITE_DELETE = 			"nyyn";
	public static final String WRITE_MANAGE = 			"nyny";
	public static final String WRITE_DELETE_MANAGE = 	"nyyy";
	public static final String DELETE_ONLY =			"nnyn";
	public static final String DELETE_MANAGE = 			"nnyy";
	public static final String MANAGE_ONLY = 			"nnny";
	public static final String ALL_PERMISSIONS = 		"yyyy";
	
	private String	path;
	private Map		entityACEs;
	private int 	numFiles;
	private int		numFolders;
	private String 	owner;
	
	ContainerEntry(String path){
		this.path = path;
		entityACEs = new HashMap();
		entityACEs.put(ContainerEntry.NO_PERMISSIONS, new UGEntity());
		entityACEs.put(ContainerEntry.READ_ONLY, new UGEntity());
		entityACEs.put(ContainerEntry.READ_WRITE, new UGEntity());
		entityACEs.put(ContainerEntry.READ_DELETE, new UGEntity());
		entityACEs.put(ContainerEntry.READ_MANAGE, new UGEntity());
		entityACEs.put(ContainerEntry.READ_WRITE_DELETE, new UGEntity());
		entityACEs.put(ContainerEntry.READ_WRITE_MANAGE, new UGEntity());
		entityACEs.put(ContainerEntry.READ_DELETE_MANAGE, new UGEntity());
		entityACEs.put(ContainerEntry.WRITE_ONLY, new UGEntity());
		entityACEs.put(ContainerEntry.WRITE_DELETE, new UGEntity());
		entityACEs.put(ContainerEntry.WRITE_MANAGE, new UGEntity());
		entityACEs.put(ContainerEntry.WRITE_DELETE_MANAGE, new UGEntity());
		entityACEs.put(ContainerEntry.DELETE_ONLY, new UGEntity());
		entityACEs.put(ContainerEntry.DELETE_MANAGE, new UGEntity());
		entityACEs.put(ContainerEntry.MANAGE_ONLY, new UGEntity());
		entityACEs.put(ContainerEntry.ALL_PERMISSIONS, new UGEntity());
	}
	
	public void setPath(String path){
		this.path = path;
	}
	
	public String getPath(){
		return path;
	}

	public Map getEntityACEs() {
		return entityACEs;
	}

	public void setEntityACEs(Map entityACEs) {
		this.entityACEs = entityACEs;
	}
	
	public int getNumFiles() {
		return numFiles;
	}

	public void setNumFiles(int numFiles) {
		this.numFiles = numFiles;
	}

	public int getNumFolders() {
		return numFolders;
	}

	public void setNumFolders(int numFolders) {
		this.numFolders = numFolders;
	}
	
	public String getOwner() {
		return owner;
	}

	public void setOwner(String owner) {
		this.owner = owner;
	}

	public void addACL(AccessControlList acl){
		List entries = acl.getEntries();
		for(Iterator iter = entries.iterator(); iter.hasNext(); ){
			AccessControlEntry ace = (AccessControlEntry)iter.next();
			addACEToMap(ace);
		}
	}

	public void addACEToMap(AccessControlEntry ace){
		String code = "";
		
		//construct the permission code
		if(ace.hasPermission(Permission.READ_PERMISSION))
			code += "y";
		else
			code += "n";
		if(ace.hasPermission(Permission.WRITE_PERMISSION))
			code += "y";
		else
			code += "n";
		if(ace.hasPermission(Permission.DELETE_PERMISSION))
			code += "y";
		else
			code += "n";
		if(ace.hasPermission(Permission.MANAGE_PERMISSION))
			code += "y";
		else
			code += "n";
		
		//add to the map
		UGEntity entity = (UGEntity)entityACEs.get(code);
		if(ace.isGroupEntry())
			entity.addGroup(ace.getName());
		else
			entity.addUser(ace.getName());
	}
}
